@@ -19,17 +19,21 @@ class _LemurImpl:
     def question(
         self,
         questions: List[types.LemurQuestion],
+        context: Optional[Union[str, Dict[str, Any]]],
         timeout: Optional[float],
         final_model: Optional[types.LemurModel],
         max_output_size: Optional[int],
+        temperature: Optional[float],
     ) -> types.LemurQuestionResponse:
         response = api.lemur_question(
             client=self._client.http_client,
             request=types.LemurQuestionRequest(
                 sources=self._sources,
                 questions=questions,
+                context=context,
                 final_model=final_model,
                 max_output_size=max_output_size,
+                temperature=temperature,
             ),
             http_timeout=timeout,
         )
@@ -43,6 +47,7 @@ class _LemurImpl:
         final_model: Optional[types.LemurModel],
         max_output_size: Optional[int],
         timeout: Optional[float],
+        temperature: Optional[float],
     ) -> types.LemurSummaryResponse:
         response = api.lemur_summarize(
             client=self._client.http_client,
@@ -52,6 +57,31 @@ class _LemurImpl:
                 answer_format=answer_format,
                 final_model=final_model,
                 max_output_size=max_output_size,
+                temperature=temperature,
+            ),
+            http_timeout=timeout,
+        )
+
+        return response
+
+    def action_items(
+        self,
+        context: Optional[Union[str, Dict[str, Any]]],
+        answer_format: Optional[str],
+        final_model: Optional[types.LemurModel],
+        max_output_size: Optional[int],
+        timeout: Optional[float],
+        temperature: Optional[float],
+    ) -> types.LemurActionItemsResponse:
+        response = api.lemur_action_items(
+            client=self._client.http_client,
+            request=types.LemurActionItemsRequest(
+                sources=self._sources,
+                context=context,
+                answer_format=answer_format,
+                final_model=final_model,
+                max_output_size=max_output_size,
+                temperature=temperature,
             ),
             http_timeout=timeout,
         )
@@ -64,6 +94,7 @@ class _LemurImpl:
         final_model: Optional[types.LemurModel],
         max_output_size: Optional[int],
         timeout: Optional[float],
+        temperature: Optional[float],
     ):
         response = api.lemur_task(
             client=self._client.http_client,
@@ -72,6 +103,7 @@ class _LemurImpl:
                 prompt=prompt,
                 final_model=final_model,
                 max_output_size=max_output_size,
+                temperature=temperature,
             ),
             http_timeout=timeout,
         )
@@ -110,9 +142,11 @@ class Lemur:
     def question(
         self,
         questions: Union[types.LemurQuestion, List[types.LemurQuestion]],
+        context: Optional[Union[str, Dict[str, Any]]] = None,
         final_model: Optional[types.LemurModel] = None,
         max_output_size: Optional[int] = None,
         timeout: Optional[float] = None,
+        temperature: Optional[float] = None,
     ) -> types.LemurQuestionResponse:
         """
         Question & Answer allows you to ask free form questions about one or many transcripts.
@@ -125,9 +159,11 @@ class Lemur:
 
         Args:
             questions: One or a list of questions to ask.
+            context: The context which is shared among all questions. This can be a string or a dictionary.
             final_model: The model that is used for the final prompt after compression is performed (options: "basic" and "default").
             max_output_size: Max output size in tokens
             timeout: The timeout in seconds to wait for the answer(s).
+            temperature: Change how deterministic the response is, with 0 being the most deterministic and 1 being the least deterministic.
 
         Returns: One or a list of answer objects.
         """
@@ -137,9 +173,11 @@ class Lemur:
 
         return self._impl.question(
             questions=questions,
+            context=context,
             final_model=final_model,
             max_output_size=max_output_size,
             timeout=timeout,
+            temperature=temperature,
         )
 
     def summarize(
@@ -149,6 +187,7 @@ class Lemur:
         final_model: Optional[types.LemurModel] = None,
         max_output_size: Optional[int] = None,
         timeout: Optional[float] = None,
+        temperature: Optional[float] = None,
     ) -> types.LemurSummaryResponse:
         """
         Summary allows you to distill a piece of audio into a few impactful sentences.
@@ -163,6 +202,7 @@ class Lemur:
             final_model: The model that is used for the final prompt after compression is performed (options: "basic" and "default").
             max_output_size: Max output size in tokens
             timeout: The timeout in seconds to wait for the summary.
+            temperature: Change how deterministic the response is, with 0 being the most deterministic and 1 being the least deterministic.
 
         Returns: The summary as a string.
         """
@@ -173,6 +213,44 @@ class Lemur:
             final_model=final_model,
             max_output_size=max_output_size,
             timeout=timeout,
+            temperature=temperature,
+        )
+
+    def action_items(
+        self,
+        context: Optional[Union[str, Dict[str, Any]]] = None,
+        answer_format: Optional[str] = None,
+        final_model: Optional[types.LemurModel] = None,
+        max_output_size: Optional[int] = None,
+        timeout: Optional[float] = None,
+        temperature: Optional[float] = None,
+    ) -> types.LemurActionItemsResponse:
+        """
+        Action Items allows you to generate action items from one or many transcripts.
+
+        You can provide the model with a context to get more pinpoint results while outputting the
+        results in a variety of formats described in human language.
+
+        See also Best Practices on LeMUR: https://www.assemblyai.com/docs/Guides/lemur_best_practices
+
+        Args:
+            context: An optional context on the transcript.
+            answer_format: The preferred format for the result action items.
+            final_model: The model that is used for the final prompt after compression is performed (options: "basic" and "default").
+            max_output_size: Max output size in tokens
+            timeout: The timeout in seconds to wait for the action items response.
+            temperature: Change how deterministic the response is, with 0 being the most deterministic and 1 being the least deterministic.
+
+        Returns: The action items as a string.
+        """
+
+        return self._impl.action_items(
+            context=context,
+            answer_format=answer_format,
+            final_model=final_model,
+            max_output_size=max_output_size,
+            timeout=timeout,
+            temperature=temperature,
         )
 
     def task(
@@ -181,6 +259,7 @@ class Lemur:
         final_model: Optional[types.LemurModel] = None,
         max_output_size: Optional[int] = None,
         timeout: Optional[float] = None,
+        temperature: Optional[float] = None,
     ) -> types.LemurTaskResponse:
         """
         Task feature allows you to submit a custom prompt to the model.
@@ -192,6 +271,7 @@ class Lemur:
             final_model: The model that is used for the final prompt after compression is performed (options: "basic" and "default").
             max_output_size: Max output size in tokens
             timeout: The timeout in seconds to wait for the task.
+            temperature: Change how deterministic the response is, with 0 being the most deterministic and 1 being the least deterministic.
 
         Returns: A response to a question or task submitted via custom prompt (with source transcripts or other sources taken into the context)
         """
@@ -201,4 +281,28 @@ class Lemur:
             final_model=final_model,
             max_output_size=max_output_size,
             timeout=timeout,
+            temperature=temperature,
+        )
+
+    @classmethod
+    def purge_request_data(
+        cls,
+        request_id: str,
+        timeout: Optional[float] = None,
+    ) -> types.LemurPurgeResponse:
+        """
+        Purge sent LeMUR request data that was previously sent.
+
+        Args:
+            request_id: The request ID that was returned to you from the original LeMUR request that should be purged.
+
+        Returns: A response saying whether the LeMUR request data was successfully purged.
+        """
+
+        return api.lemur_purge_request_data(
+            client=_client.Client.get_default().http_client,
+            request=types.LemurPurgeRequest(
+                request_id=request_id,
+            ),
+            http_timeout=timeout,
         )
