@@ -272,6 +272,12 @@ class Transcript(types.Sourcable):
 
         return self._impl.config
 
+    @property
+    def json_response(self) -> Optional[dict]:
+        "The full JSON response associated with the transcript."
+
+        return self._impl.transcript.dict()
+
     @property
     def audio_url(self) -> str:
         "The corresponding audio url"
@@ -861,6 +867,25 @@ class Transcriber:
             poll=False,
         )
 
+    def submit_group(
+        self,
+        data: List[str],
+        config: Optional[types.TranscriptionConfig] = None,
+    ) -> TranscriptGroup:
+        """
+        Submits multiple transcription jobs without waiting for their completion.
+
+        Args:
+            data: A list of paths or URLs (can be mixed)
+            config: Transcription options and features. If `None` is given, the Transcriber's
+                default configuration will be used.
+        """
+        return self._impl.transcribe_group(
+            data=data,
+            config=config,
+            poll=False,
+        )
+
     def transcribe(
         self,
         data: str,
@@ -987,7 +1012,7 @@ class _RealtimeTranscriberImpl:
             "sample_rate": self._sample_rate,
         }
         if self._word_boost:
-            params["word_boost"] = self._word_boost
+            params["word_boost"] = json.dumps(self._word_boost)
 
         websocket_base_url = self._client.settings.base_url.replace("https", "wss")
 
