@@ -97,6 +97,9 @@ class LanguageCode(str, Enum):
     Supported languages for Transcribing Audio
     """
 
+    de = "de"
+    "German"
+
     en = "en"
     "Global English"
 
@@ -109,8 +112,11 @@ class LanguageCode(str, Enum):
     en_us = "en_us"
     "English (US)"
 
-    de = "de"
-    "German"
+    es = "es"
+    "Spanish"
+
+    fi = "fi"
+    "Finnish"
 
     fr = "fr"
     "French"
@@ -124,15 +130,33 @@ class LanguageCode(str, Enum):
     ja = "ja"
     "Japanese"
 
-    es = "es"
-    "Spanish"
+    ko = "ko"
+    "Korean"
 
     nl = "nl"
     "Dutch"
 
+    pl = "pl"
+    "Polish"
+
     pt = "pt"
     "Portuguese"
 
+    ru = "ru"
+    "Russian"
+
+    tr = "tr"
+    "Turkish"
+
+    uk = "uk"
+    "Ukrainian"
+
+    vi = "vi"
+    "Vietnamese"
+
+    zh = "zh"
+    "Chinese"
+
 
 class WordBoost(str, Enum):
     low = "low"
@@ -802,7 +826,7 @@ class TranscriptionConfig:
         "Enable Auto Chapters."
 
         # Validate required params are also set
-        if self.punctuate == False:
+        if enable and self.punctuate == False:
             raise ValueError(
                 "If `auto_chapters` is enabled, then `punctuate` must not be disabled"
             )
@@ -954,7 +978,7 @@ class TranscriptionConfig:
 
             return self
 
-        self._raw_transcription_config.url = url
+        self._raw_transcription_config.webhook_url = url
         if auth_header_name and auth_header_value:
             self._raw_transcription_config.webhook_auth_header_name = auth_header_name
             self._raw_transcription_config.webhook_auth_header_value = auth_header_value
@@ -1395,6 +1419,8 @@ class BaseTranscript(BaseModel):
     "The URL we should send webhooks to when your transcript is complete."
     webhook_auth_header_name: Optional[str]
     "The name of the header that is sent when the `webhook_url` is being called."
+    webhook_auth_header_value: Optional[str]
+    "The value of the `webhook_auth_header_name` that is sent when the `webhook_url` is being called."
 
     audio_start_from: Optional[int]
     "The point in time, in milliseconds, to begin transcription from in your media file."
@@ -1421,6 +1447,9 @@ class BaseTranscript(BaseModel):
     speaker_labels: Optional[bool]
     "Enable Speaker Diarization."
 
+    speakers_expected: Optional[int]
+    "The number of speakers you expect to be in your audio file."
+
     content_safety: Optional[bool]
     "Enable Content Safety Detection."
 
@@ -1734,6 +1763,7 @@ class BaseLemurRequest(BaseModel):
     sources: List[LemurSourceRequest]
     final_model: Optional[LemurModel]
     max_output_size: Optional[int]
+    temperature: Optional[float]
 
 
 class LemurTaskRequest(BaseLemurRequest):
@@ -1749,6 +1779,7 @@ class LemurTaskResponse(BaseModel):
 
 
 class LemurQuestionRequest(BaseLemurRequest):
+    context: Optional[Union[str, Dict[str, Any]]]
     questions: List[LemurQuestion]
 
 
@@ -1781,6 +1812,42 @@ class LemurSummaryResponse(BaseModel):
     "The summary of your LeMUR request"
 
 
+class LemurActionItemsRequest(BaseLemurRequest):
+    context: Optional[Union[str, Dict[str, Any]]]
+    answer_format: Optional[str]
+
+
+class LemurActionItemsResponse(BaseModel):
+    """
+    The result of your Action Items LeMUR request.
+    """
+
+    request_id: str
+    "The unique identifier of your LeMUR request"
+
+    response: str
+    "The action items for your LeMUR request"
+
+
+class LemurPurgeRequest(BaseModel):
+    request_id: str
+
+
+class LemurPurgeResponse(BaseModel):
+    """
+    The result of your LeMUR purge request.
+    """
+
+    request_id: str
+    "The unique identifier of the LeMUR purge request"
+
+    request_id_to_purge: str
+    "The unique identifier of the LeMUR request nneds to be purged"
+
+    deleted: bool
+    "The result of the LeMUR purge request"
+
+
 class RealtimeMessageTypes(str, Enum):
     """
     The type of message received from the real-time API
