@@ -5,7 +5,10 @@ import pytest
 from pytest_httpx import HTTPXMock
 
 import assemblyai as aai
-from assemblyai.api import ENDPOINT_LEMUR
+from assemblyai.api import (
+    ENDPOINT_LEMUR,
+    ENDPOINT_LEMUR_BASE,
+)
 from tests.unit import factories
 
 aai.settings.api_key = "test"
@@ -152,7 +155,9 @@ def test_lemur_summarize_succeeds(httpx_mock: HTTPXMock):
     """
 
     # create a mock response of a LemurSummaryResponse
-    mock_lemur_summary = factories.generate_dict_factory(factories.LemurTaskResponse)()
+    mock_lemur_summary = factories.generate_dict_factory(
+        factories.LemurSummaryResponse
+    )()
 
     # mock the specific endpoints
     httpx_mock.add_response(
@@ -204,6 +209,72 @@ def test_lemur_summarize_fails(httpx_mock: HTTPXMock):
     assert len(httpx_mock.get_requests()) == 1
 
 
+def test_lemur_action_items_succeeds(httpx_mock: HTTPXMock):
+    """
+    Tests whether generating action items for a transcript via LeMUR succeeds.
+    """
+
+    # create a mock response of a LemurActionItemsResponse
+    mock_lemur_action_items = factories.generate_dict_factory(
+        factories.LemurActionItemsResponse
+    )()
+
+    # mock the specific endpoints
+    httpx_mock.add_response(
+        url=f"{aai.settings.base_url}{ENDPOINT_LEMUR}/action-items",
+        status_code=httpx.codes.OK,
+        method="POST",
+        json=mock_lemur_action_items,
+    )
+
+    # mimic the usage of the SDK
+    transcript = aai.Transcript(str(uuid.uuid4()))
+
+    lemur = aai.Lemur(sources=[aai.LemurSource(transcript)])
+    result = lemur.action_items(
+        context="Customers asking for help with resolving their problem",
+        answer_format="Three bullet points",
+    )
+
+    assert isinstance(result, aai.LemurActionItemsResponse)
+
+    action_items = result.response
+
+    # check the response
+    assert action_items == mock_lemur_action_items["response"]
+
+    # check whether we mocked everything
+    assert len(httpx_mock.get_requests()) == 1
+
+
+def test_lemur_action_items_fails(httpx_mock: HTTPXMock):
+    """
+    Tests whether generating action items for a transcript via LeMUR fails.
+    """
+
+    # mock the specific endpoints
+    httpx_mock.add_response(
+        url=f"{aai.settings.base_url}{ENDPOINT_LEMUR}/action-items",
+        status_code=httpx.codes.INTERNAL_SERVER_ERROR,
+        method="POST",
+        json={"error": "something went wrong"},
+    )
+
+    # mimic the usage of the SDK
+    transcript = aai.Transcript(str(uuid.uuid4()))
+
+    lemur = aai.Lemur(sources=[aai.LemurSource(transcript)])
+
+    with pytest.raises(aai.LemurError):
+        lemur.action_items(
+            context="Customers asking for help with resolving their problem",
+            answer_format="Three bullet points",
+        )
+
+    # check whether we mocked everything
+    assert len(httpx_mock.get_requests()) == 1
+
+
 def test_lemur_task_succeeds(httpx_mock: HTTPXMock):
     """
     Tests whether creating a task request succeeds.
@@ -262,3 +333,59 @@ def test_lemur_ask_coach_fails(httpx_mock: HTTPXMock):
 
     # check whether we mocked everything
     assert len(httpx_mock.get_requests()) == 1
+
+
+def test_lemur_purge_request_data_succeeds(httpx_mock: HTTPXMock):
+    """
+    Tests whether LeMUR request purging succeeds.
+    """
+
+    # create a mock response of a LemurPurgeResponse
+    mock_lemur_purge_response = factories.generate_dict_factory(
+        factories.LemurPurgeResponse
+    )()
+
+    mock_request_id: str = str(uuid.uuid4())
+
+    # mock the specific endpoints
+    httpx_mock.add_response(
+        url=f"{aai.settings.base_url}{ENDPOINT_LEMUR_BASE}/{mock_request_id}",
+        status_code=httpx.codes.OK,
+        method="DELETE",
+        json=mock_lemur_purge_response,
+    )
+
+    # mimic the usage of the SDK
+    result = aai.Lemur.purge_request_data(request_id=mock_request_id)
+
+    # check the response
+    assert isinstance(result, aai.LemurPurgeResponse)
+
+    # check whether we mocked everything
+    assert len(httpx_mock.get_requests()) == 1
+
+
+def test_lemur_purge_request_data_fails(httpx_mock: HTTPXMock):
+    """
+    Tests whether LeMUR request purging fails.
+    """
+
+    # create a mock response of a LemurPurgeResponse
+    mock_lemur_purge_response = factories.generate_dict_factory(
+        factories.LemurPurgeResponse
+    )()
+
+    mock_request_id: str = str(uuid.uuid4())
+
+    # mock the specific endpoints
+    httpx_mock.add_response(
+        url=f"{aai.settings.base_url}{ENDPOINT_LEMUR_BASE}/{mock_request_id}",
+        status_code=httpx.codes.INTERNAL_SERVER_ERROR,
+        method="DELETE",
+        json=mock_lemur_purge_response,
+    )
+
+    with pytest.raises(aai.LemurError) as error:
+        aai.Lemur.purge_request_data(mock_request_id)
+
+    assert len(httpx_mock.get_requests()) == 1
